@@ -147,6 +147,8 @@ int countDigit(uint64_t n);
 std::string find_file_in_folder(const std::string& folder,
                const std::string& regex);
 uint64_t get_multiplier_from_char(char units_char);
+rsmi_status_t check_runtime_pm_status(uint32_t dv_ind, bool *is_suspended);
+rsmi_status_t wake_device(uint32_t dv_ind);
 template <typename T>
   std::string print_int_as_hex(T i, bool showHexNotation = true,
   int overloadBitSize = 0) {
